# Demonstration script for JACOsub video titling software.

# You might want to print out a hard copy of this script, and refer to it
# while you play the script in Step Mode.

# This script demonstrates the flexibility of the JACOsub file format,
# going through nearly all of the features available.  Don't be alarmed
# by the size; this script consists mostly of comments.  The running time
# is just over a minute.

# You can load TurboTitle, Generic, and Arizona Anime Society format
# scripts directly into JACOsub, which will automatically convert them
# to JACOsub format.  However, for these and other formats (such as
# Panimator) you should convert them using Jconvert before loading them
# into JACOsub to correct bad time-overlaps in those scripts.

# Now let's begin.  All the directives and commands demonstrated in this
# script are shown in UPPERCASE the first time they are used.

  # First, let's set up some defaults.  Time units default to SMPTE
  # (1/30 second) units.  We'll use 1/100 seconds because it's simpler to
  # understand for now.
  # Note: All # commands may be specified by a single letter.  For example,
  # below we could use #T instead of #TIMERES.

#TIMERES 100

  # Next, suppose this script consisted of subtitles played against a
  # foreign film, and we noticed that the time events were drifting so that
  # by the end of the script, the subtitles were occurring 2.2 seconds too
  # soon.  This means we need to stretch the script's total running time
  # by 2.2 seconds to correct the drift.  The #Ramp command does this.  The
  # number past the decimal point is time units (in 1/100 seconds as
  # specified by the #T command above), not fractions of a second.

#RAMP 2.20

  # Set font 3 for use near the end of this script, where we demonstrate
  # outlining and shadowing of mono-color fonts.  JACOsub.font 18 is a
  # mono-color font which JACOsub uses for its running clock display.

#FONT 3 JACOsub.font 18

  # Let's change some default colors while we're at it....

#P1  0 14 14     (set "slow text" color 1 of primary palette to cyan)
#p3 14  0  0  1  (set color 3 of palette 1 to red)

  # Now we will start with the list of timed lines.  Each timed line has
  # the format
  # <start time> <stop time> <directive> <text>

  # Just for the fun of it, let's load in an IFF file
  # to serve as a backdrop for the first few titles.

0:00:00.00 0:00.09.00 IL JACO.bbm 0 0 {logo will be centered on the screen}

  # Now, show an introductory title centered on the screen for 4 seconds.
  # This line demonstrates the newline escape character, or manual
  # wordwrap.  The new substrings created will also be word-wrapped
  # automatically if they don't fit within the default width limits.
  # You can also turn wordwrapping off for a line with the W0 directive.

  # Notice also that the concatenation escape code (the \ at the end of
  # each line) is NOT the same as a newline in your text.  The ending \
  # character means to assume that the next line is a continuous part of
  # the current one.  It works even if you break a word at the end.
  # Concatenation ignores all space after the \ and all space before the
  # first character on the line that follows the \.

0:00:00.00 0:00:04.00 VM JACOsub\n\nThis script demonstrates \
                         some of the capabilities of JACOsub.

  # The next 3 lines demonstrate vertical positioning and overlapping time
  # ranges.  Notice how the times for each of the lines are set.  All three
  # lines are present on the screen only between times 5.50 and 6.50.

0:00:04.00 0:00:05.50 VT Text may be positioned at the top,
0:00:05.00 0:00:06.50 vm middle,
0:00:06.00 0:00:07.50 VB or bottom of the screen.

  # The next line shows how you can insert comments inside the text.  This
  # is useful for making notes about translations and character names when
  # subtitling foreign films.  Here we also demonstrate how Italics (\I)
  # and Normal (\N) escape codes can be embedded in the title text.

0:00:08.00 0:00:11.00 vm {this is a comment} (And, you can see, {another \
                         comment} timing ranges for different lines of \
                         text \Iand\N graphics may overlap.)

  # Here we demonstrate that graphics can also be overlapped in time.

0:00:9.50 0:00:12.60 il JACO.bbm 25 25    {place logo lower right}

  # Now we demonstrate left/right/center justification

0:00:11.00 0:00:13.50 JL Within margin constraints\n\
                         that you set, text may be\nleft justified,
0:00:13.50 0:00:14.75 JC {the JC is redundant - it's the default}\
                         center\njustified,
0:00:14.75 0:00:16.00 JR and also\nright justified.

  # Here we show what you can do with margin settings.  The first line
  # sets the right margin to 33% of the screen (left margin is at 1%), and
  # the second line sets the left margin at 50% of the screen (right
  # margin is at 99%).  We also demonstrate two fonts on the same screen.

0:00:15.60 0:00:22.00 vtHR33   You can, for example, set your margins \
               so that text is confined to the left 1/3 of the screen.
0:00:17.50 0:00:22.00 vbHL50F1 And you can place other text elsewhere \
         (with a different font, even) by setting different margins for it.

  # Now we demonstrate different text styles and colors.  Notice here we
  # use the VL directive to position the text on different lines.

0:00:22.30 0:00:28.00 VL3 You may have different text styles\n(Normal, \BBold, \IItalic\N)
0:00:22.30 0:00:28.00 vl5 and different \C1colors
                      # Notice here the default text color has been
                      # changed to 1 and restored to 3 inside the text.
0:00:24.00 0:00:28.00 CF1vl7 all \C3mixed \C1\Itogether.

  # On the same screen, demonstrate loading in a different color palette
  # so that another color appears (color 3=red as defined in Palette 1).

0:00:26.00 0:00:28.00 CP1vl8 (even with different palettes.)

  # Here's a trick.  We will rapidly cycle through some blank screens
  # so that the current display will "catch up" to the background display
  # buffer being generated.  We use color 1 text here, which is slow.

0:00:28.01 0:00:28.02 D ~
0:00:28.02 0:00:28.03 D ~
0:00:28.03 0:00:28.04 D ~
0:00:28.04 0:00:28.05 D ~

  # But before we do that, just for fun, let's define directive D2 as
  # CF1VM to use in the next line, for
  # "Color Fontface 1, Vertical position Middle."

#d2 CF1VM

0:00:28.05 0:00:32.00 D2 Here the display was intentionally ``caught up'' \
                         to the background generation, to show how slowly \
                         color 1 text is generated in the background.

  # In the next title, lots of things happen at once.  We demonstrate
  # Three things: block justification with word justification, the vertical
  # continuation directive, and background shading.

  # The first title after this comment demonstrates the JB (Justify Block)
  # directive.  Text is left-justified, but it is not positioned flush with
  # the left margin - the block of text is centered on the screen but the
  # first character of each line are flush left.  In other words, the JL
  # means "left justify" but JBC means "center block."

  # The next title demonstrates the VU directive to show how you can
  # continue a long line of text underneath previous ones.
  # Here we also demonstrates background shading -- a semi-transparent
  # rectangle will appear behind the text, 8 pixels larger than the text
  # all around.

0:00:32.30 0:00:43.00 d2jlJBC \
   You will see that sort of foreground generation if you use a lot of \
   ``slow'' color 1 text.\n\C3(Color 3 text is very fast.)
0:00:32.30 0:00:43.00 VUcf1CS8 \n\n\Plan your timings so the display won't catch up to the view being generated in the background.

  # Demonstrate backgrounds that are opaque to the genlock, by specifying
  # a background color.  This will clear the whole screen to that color
  # before any text is drawn on it, and before any IFF files are overlaid
  # onto it.

0:00:43.00 0:00:50.00 CB1vm You can change the screen background color, too.\
\n\nThis is useful if you want to make an opaque screen when using a genlock.

  # Demonstrate the #Include command.
  # The VH and CSL directives are demonstrated in the #included script.

#I 0:00:50.00 idemo  # include another script, offset by 50 seconds

  # Outlining and shadowing.  The first and second lines show outlining
  # a mono-color font.  The third line demonstrates font shadow generation.
  # The shadow extends to the southwest (lower left).  The fourth line
  # demonstrates both outlining and shadowing (to the southeast).  We use
  # font 3 for all these four lines (font 3 was set to JACOsub.font 18 in
  # the beginning of this script).

0:00:58.00 0:01:05.00 FO2f3vm JACOsub can also generate outlines of any thickness around normal mono-colored fonts,
0:00:58.00 0:01:05.00 fo3f3vu as you can see here.
0:00:58.00 0:01:05.00 FSSW4f3vu    \nAlso, dropshadows in any of 8 directions are possible,
0:00:58.00 0:01:05.00 fsSE3fo2f3vu \nand outlines and shadows may be combined.

  # Demonstrate clock pausing.  This is useful for making a single script
  # to handle multiple sides of a laserdisc.

0:01:05.00 0:01:06.00 vm Right now the clock is paused (you can see this \
                         if you play the script using the clock display).\n
0:01:05.00 0:01:06.00 vuf1cf1 Press any key to continue playing, or ESC to abort.
#CLOCKPAUSE 0:01:05.00

  # Show the last screen.  We'll use the alternate frame-count format for
  # the start and stop times.  For this script, there are 100 counts per
  # second.  Normally this format would be used when the time resolution
  # is 30 per second (which would have been the default if #T100 wasn't
  # specified at the beginning of the script).
  # The times below correspond to 0:01:06.00 and 0:01:11.00.

@0006600 @0007100 vm OK, this script will be finished when the screen goes blank.
@0006600 @0007100 vu \n\nAt that time, you may press any key to return to the Editor.

# You probably noticed that most of the lines above used the VM (Vertical
# Middle) directive.  We could have made this the default, by specifying
# the global command #DVM near the beginning of the file.  Then we
# wouldn't have had to specify VM on each line, but we would have had to
# specify VB (the former default) for those lines positioned at the bottom
# of the screen.
